Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(638)

Unified Diff: components/sync/driver/model_type_controller_unittest.cc

Issue 2533083002: [Sync] SyncEngine refactor part 1: interfaces. (Closed)
Patch Set: Rebase. Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/sync/driver/model_type_controller_unittest.cc
diff --git a/components/sync/driver/model_type_controller_unittest.cc b/components/sync/driver/model_type_controller_unittest.cc
index fd6bb598b6d172a0bc7110956d616296fd72a70d..c675192f9f41ec5d15bc8bb9a76c5c59d6fefcc6 100644
--- a/components/sync/driver/model_type_controller_unittest.cc
+++ b/components/sync/driver/model_type_controller_unittest.cc
@@ -18,11 +18,11 @@
#include "base/test/test_simple_task_runner.h"
#include "base/threading/thread.h"
#include "base/threading/thread_task_runner_handle.h"
-#include "components/sync/driver/backend_data_type_configurer.h"
#include "components/sync/driver/fake_sync_client.h"
#include "components/sync/engine/activation_context.h"
#include "components/sync/engine/commit_queue.h"
#include "components/sync/engine/fake_model_type_processor.h"
+#include "components/sync/engine/model_type_configurer.h"
#include "components/sync/engine/model_type_processor_proxy.h"
#include "components/sync/model/fake_model_type_change_processor.h"
#include "components/sync/model/stub_model_type_sync_bridge.h"
@@ -70,11 +70,11 @@ class TestModelTypeProcessor : public FakeModelTypeChangeProcessor,
DISALLOW_COPY_AND_ASSIGN(TestModelTypeProcessor);
};
-// A BackendDataTypeConfigurer that just connects USS types.
-class TestBackendDataTypeConfigurer : public BackendDataTypeConfigurer {
+// A ModelTypeConfigurer that just connects USS types.
+class TestModelTypeConfigurer : public ModelTypeConfigurer {
public:
- TestBackendDataTypeConfigurer() {}
- ~TestBackendDataTypeConfigurer() override {}
+ TestModelTypeConfigurer() {}
+ ~TestModelTypeConfigurer() override {}
ModelTypeSet ConfigureDataTypes(
ConfigureReason reason,
@@ -251,7 +251,7 @@ class ModelTypeControllerTest : public testing::Test, public FakeSyncClient {
base::MessageLoop message_loop_;
base::Thread model_thread_;
SyncPrefs sync_prefs_;
- TestBackendDataTypeConfigurer configurer_;
+ TestModelTypeConfigurer configurer_;
std::unique_ptr<StubModelTypeSyncBridge> bridge_;
std::unique_ptr<ModelTypeController> controller_;
TestModelTypeProcessor* processor_;
« no previous file with comments | « components/sync/driver/model_type_controller.cc ('k') | components/sync/driver/proxy_data_type_controller.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698